@@ -11,6 +11,7 @@ Functionality for logging in pyzo.
 
 """
 
+import os
 import sys, time
 import pyzo
 
@@ -28,7 +29,7 @@ except AttributeError:
 
 
 class DummyStd:
-    """ For when std is not available. """
+    """For when std is not available."""
 
     def __init__(self):
         self._closed = False
@@ -120,9 +121,12 @@ class OutputStreamSplitter:
         pass
 
     def write(self, text):
-        """ Write method. """
+        """Write method."""
         self._original.write(text)
         self._history.append(text)
+        if os.getenv("PYZO_LOG", ""):
+            with open(os.getenv("PYZO_LOG"), "at") as f:
+                f.write(text)
         try:
             self._deferFunction(text)
         except Exception:
