@@ -12,7 +12,7 @@ Implements shell configuration dialog.
 """
 
 import os, sys
-from pyzo.util.qt import QtCore, QtGui, QtWidgets  # noqa
+from pyzo.qt import QtCore, QtGui, QtWidgets  # noqa
 
 import pyzo
 from pyzo.core.pyzoLogging import print
@@ -125,10 +125,12 @@ class ShellInfo_gui(QtWidgets.QComboBox):
         ("None", "no GUI support"),
         ("Auto", "Use what is available (recommended)"),
         ("Asyncio", "Python's builtin event loop"),
-        ("PyQt5", "GPL/commercial licensed wrapper to Qt"),
-        ("PyQt4", "GPL/commercial licensed wrapper to Qt"),
-        ("PySide", "LGPL licensed wrapper to Qt"),
+        ("PySide6", "LGPL licensed wrapper to Qt6"),
         ("PySide2", "LGPL licensed wrapper to Qt5"),
+        ("PySide", "LGPL licensed wrapper to Qt4"),
+        ("PyQt6", "GPL/commercial licensed wrapper to Qt5"),
+        ("PyQt5", "GPL/commercial licensed wrapper to Qt5"),
+        ("PyQt4", "GPL/commercial licensed wrapper to Qt4"),
         ("Tornado", "Tornado asynchronous networking library"),
         ("Tk", "Tk widget toolkit"),
         ("WX", "wxPython"),
@@ -568,7 +570,7 @@ class ShellInfoTab(QtWidgets.QScrollArea):
 
 
 class ShellInfoDialog(QtWidgets.QDialog):
-    """ Dialog to edit the shell configurations. """
+    """Dialog to edit the shell configurations."""
 
     def __init__(self, *args):
         QtWidgets.QDialog.__init__(self, *args)
@@ -654,7 +656,7 @@ class ShellInfoDialog(QtWidgets.QDialog):
         self.close()
 
     def apply(self):
-        """ Apply changes for all tabs. """
+        """Apply changes for all tabs."""
 
         # Clear
         pyzo.config.shellConfigs2 = []
