@@ -13,7 +13,7 @@ Defines splash window shown during startup.
 import os
 
 import pyzo
-from pyzo.util.qt import QtCore, QtGui, QtWidgets  # noqa
+from pyzo.qt import QtCore, QtGui, QtWidgets  # noqa
 from pyzo import translate
 
 STYLESHEET = """
