@@ -1,6 +1,6 @@
 import os
 
-from pyzo.util.qt import QtCore, QtGui, QtWidgets
+from pyzo.qt import QtCore, QtGui, QtWidgets
 
 import pyzo
 from pyzo.util import zon as ssdf
@@ -113,8 +113,8 @@ class ColorLineEdit(QtWidgets.QLineEdit):
         buttonSize = self.button.sizeHint()
         frameWidth = self.style().pixelMetric(QtWidgets.QStyle.PM_DefaultFrameWidth)
         self.button.move(
-            self.rect().right() - frameWidth - buttonSize.width(),
-            (self.rect().bottom() - buttonSize.height() + 1) / 2,
+            int(self.rect().right() - frameWidth - buttonSize.width()),
+            int(self.rect().bottom() - buttonSize.height() + 1) // 2,
         )
         super().resizeEvent(event)
 
@@ -217,7 +217,7 @@ class StyleEdit(QtWidgets.QWidget):
         self.styleChanged.emit(self.styleKey, key + ":" + value)
 
     def setStyle(self, text):
-        """ updates every children to match the StyleFormat(text) fields"""
+        """updates every children to match the StyleFormat(text) fields"""
         style = StyleFormat(text)
         for key, setter in self.setters.items():
             setter(style[key])
