@@ -18,8 +18,8 @@ We integrate IPython via the IPython.core.interactiveshell.InteractiveShell.
   * Debugging occurs in our own debugger
   * GUI integration is all handled by pyzo
   * We need special prompts for IPython input
-  
-  
+
+
 
 """
 
@@ -118,7 +118,6 @@ class PyzoInterpreter:
       * introspector: the introspector instance (a subclassed yoton.RepChannel)
       * magician: the object that handles the magic commands
       * guiApp: a wrapper for the integrated GUI application
-      * sleeptime: the amount of time (in seconds) to sleep at each iteration
 
     """
 
@@ -159,10 +158,6 @@ class PyzoInterpreter:
         # Init buffer to deal with multi-line command in the shell
         self._buffer = []
 
-        # Init sleep time. 0.001 result in 0% CPU usage at my laptop (Windows),
-        # but 8% CPU usage at my older laptop (on Linux).
-        self.sleeptime = 0.01  # 100 Hz
-
         # Create compiler
         if sys.platform.startswith("java"):
             import compiler
@@ -221,7 +216,7 @@ class PyzoInterpreter:
 
         # Enter main
         try:
-            self.guiApp.run(self.process_commands, self.sleeptime)
+            self.guiApp.run(self.process_commands)
         except SystemExit:
             # Set self._exitException if it is not set yet
             type, value, tb = sys.exc_info()
@@ -488,7 +483,7 @@ class PyzoInterpreter:
         event loop).
         """
 
-        self.guiApp = guiintegration.App_base()
+        self.guiApp = guiintegration.App_nogui()
         self.guiName = guiName = startup_info["gui"].upper()
         guiError = ""
 
@@ -497,12 +492,14 @@ class PyzoInterpreter:
                 guiName = ""
             elif guiName == "AUTO":
                 for tryName, tryApp in [
-                    ("PYQT5", guiintegration.App_pyqt5),
-                    ("PYQT4", guiintegration.App_pyqt4),
+                    ("PYSIDE6", guiintegration.App_pyside6),
+                    ("PYQT6", guiintegration.App_pyqt6),
                     ("PYSIDE2", guiintegration.App_pyside2),
+                    ("PYQT5", guiintegration.App_pyqt5),
                     ("PYSIDE", guiintegration.App_pyside),
+                    ("PYQT4", guiintegration.App_pyqt4),
                     # ('WX', guiintegration.App_wx),
-                    ("ASYNCIO", guiintegration.App_asyncio),
+                    ("ASYNCIO", guiintegration.App_asyncio_new),
                     ("TK", guiintegration.App_tk),
                 ]:
                     try:
@@ -514,17 +511,21 @@ class PyzoInterpreter:
                 else:
                     guiName = ""
             elif guiName == "ASYNCIO":
-                self.guiApp = guiintegration.App_asyncio()
+                self.guiApp = guiintegration.App_asyncio_new()
             elif guiName == "TK":
                 self.guiApp = guiintegration.App_tk()
             elif guiName == "WX":
                 self.guiApp = guiintegration.App_wx()
             elif guiName == "TORNADO":
                 self.guiApp = guiintegration.App_tornado()
-            elif guiName == "PYSIDE":
-                self.guiApp = guiintegration.App_pyside()
+            elif guiName == "PYSIDE6":
+                self.guiApp = guiintegration.App_pyside6()
             elif guiName == "PYSIDE2":
                 self.guiApp = guiintegration.App_pyside2()
+            elif guiName == "PYSIDE":
+                self.guiApp = guiintegration.App_pyside()
+            elif guiName in ["PYQT6", "QT6"]:
+                self.guiApp = guiintegration.App_pyqt6()
             elif guiName in ["PYQT5", "QT5"]:
                 self.guiApp = guiintegration.App_pyqt5()
             elif guiName in ["PYQT4", "QT4"]:
@@ -809,7 +810,7 @@ class PyzoInterpreter:
                 return False
 
     def runlargecode(self, msg, silent=False):
-        """ To execute larger pieces of code. """
+        """To execute larger pieces of code."""
 
         # Get information
         source, fname, lineno = msg["source"], msg["fname"], msg["lineno"]
@@ -899,7 +900,7 @@ class PyzoInterpreter:
             self.write("Could not run code because it is incomplete.\n")
 
     def runfile(self, fname):
-        """  To execute the startup script. """
+        """To execute the startup script."""
 
         # Get text (make sure it ends with a newline)
         try:
@@ -1056,7 +1057,7 @@ class PyzoInterpreter:
     ## Writing and error handling
 
     def write(self, text):
-        """ Write errors. """
+        """Write errors."""
         sys.stderr.write(text)
 
     def showsyntaxerror(self, filename=None):
