@@ -44,7 +44,7 @@ import os.path as op
 
 import pyzo
 from pyzo.util import zon as ssdf
-from pyzo.util.qt import QtCore, QtGui, QtWidgets  # noqa
+from pyzo.qt import QtCore, QtGui, QtWidgets  # noqa
 
 from .browser import Browser
 from .utils import cleanpath, isdir
