@@ -12,18 +12,18 @@ c3 = yoton.Context(verbosity)
 c4 = yoton.Context(verbosity)
 
 # Connect in a row
-addr = 'localhost:whop'
-c1.bind(addr+'+1')
-c2.connect(addr+'+1')
-c2.bind(addr+'+2')
-c3.connect(addr+'+2')
-c3.bind(addr+'+3')
-c4.connect(addr+'+3')
+addr = "localhost:whop"
+c1.bind(addr + "+1")
+c2.connect(addr + "+1")
+c2.bind(addr + "+2")
+c3.connect(addr + "+2")
+c3.bind(addr + "+3")
+c4.connect(addr + "+3")
 
 # Create pub at first and sub at last
-p = yoton.PubChannel(c1, 'hop')
-s = yoton.SubChannel(c4, 'hop')
+p = yoton.PubChannel(c1, "hop")
+s = yoton.SubChannel(c4, "hop")
 
 # Send a message.
-p.send('hophophop')
+p.send("hophophop")
 print(s.recv())
